@@ -231,35 +231,35 @@ def LazyBear(df,length,mult,length_KC,mult_KC,crucescompra,crucesventa,usarvola)
     # 1. la cruz negra se vuelve gris (se suelta el apretón)
 
     if crucescompra==1:
-        long_cond1 =  (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True) 
+        long_cond1 =   (df['squeeze_off'].iloc[-1] == True) 
     elif crucescompra==2:
-        long_cond1 =  (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True) 
+        long_cond1 =   (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True) 
     elif crucescompra==3:
-        long_cond1 = (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==4:
-        long_cond1 = (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==5:
-        long_cond1 = (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==6:
-        long_cond1 = (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==7:
-        long_cond1 = (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==8:
-        long_cond1 = (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==9:
-        long_cond1 = (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==10:
-        long_cond1 = (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==11:
-        long_cond1 = (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==12:
-        long_cond1 = (df['squeeze_off'].iloc[-13] == False) & (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-12] == True) & (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==13:
-        long_cond1 = (df['squeeze_off'].iloc[-14] == False) & (df['squeeze_off'].iloc[-13] == False) & (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-13] == True) & (df['squeeze_off'].iloc[-12] == True) & (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==14:
-        long_cond1 = (df['squeeze_off'].iloc[-15] == False) & (df['squeeze_off'].iloc[-14] == False) & (df['squeeze_off'].iloc[-13] == False) & (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-14] == True) & (df['squeeze_off'].iloc[-13] == True) & (df['squeeze_off'].iloc[-12] == True) & (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucescompra==15:
-        long_cond1 = (df['squeeze_off'].iloc[-16] == False) & (df['squeeze_off'].iloc[-15] == False) & (df['squeeze_off'].iloc[-14] == False) & (df['squeeze_off'].iloc[-13] == False) & (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        long_cond1 =  (df['squeeze_off'].iloc[-15] == True) & (df['squeeze_off'].iloc[-14] == True) & (df['squeeze_off'].iloc[-13] == True) & (df['squeeze_off'].iloc[-12] == True) & (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
 
 
 
@@ -277,35 +277,35 @@ def LazyBear(df,length,mult,length_KC,mult_KC,crucescompra,crucesventa,usarvola)
     # 1. la cruz negra se vuelve gris (se suelta el apretón)
 
     if crucesventa==1:
-        short_cond1 =  (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True) 
+        short_cond1 = (df['squeeze_off'].iloc[-1] == True) 
     elif crucesventa==2:
-        short_cond1 =  (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True) 
+        short_cond1 =   (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True) 
     elif crucesventa==3:
-        short_cond1 = (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 = (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==4:
-        short_cond1 = (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==5:
-        short_cond1 = (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==6:
-        short_cond1 = (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==7:
-        short_cond1 = (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==8:
-        short_cond1 = (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==9:
-        short_cond1 = (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==10:
-        short_cond1 = (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==11:
-        short_cond1 = (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==12:
-        short_cond1 = (df['squeeze_off'].iloc[-13] == False) & (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-12] == True) & (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==13:
-        short_cond1 = (df['squeeze_off'].iloc[-14] == False) & (df['squeeze_off'].iloc[-13] == False) & (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-13] == True) & (df['squeeze_off'].iloc[-12] == True) & (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==14:
-        short_cond1 = (df['squeeze_off'].iloc[-15] == False) & (df['squeeze_off'].iloc[-14] == False) & (df['squeeze_off'].iloc[-13] == False) & (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-14] == True) & (df['squeeze_off'].iloc[-13] == True) & (df['squeeze_off'].iloc[-12] == True) & (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
     elif crucesventa==15:
-        short_cond1 = (df['squeeze_off'].iloc[-16] == False) & (df['squeeze_off'].iloc[-15] == False) & (df['squeeze_off'].iloc[-14] == False) & (df['squeeze_off'].iloc[-13] == False) & (df['squeeze_off'].iloc[-12] == False) & (df['squeeze_off'].iloc[-11] == False) & (df['squeeze_off'].iloc[-10] == False) & (df['squeeze_off'].iloc[-9] == False) & (df['squeeze_off'].iloc[-8] == False) & (df['squeeze_off'].iloc[-7] == False) & (df['squeeze_off'].iloc[-6] == False) & (df['squeeze_off'].iloc[-5] == False) & (df['squeeze_off'].iloc[-4] == False) & (df['squeeze_off'].iloc[-3] == False) & (df['squeeze_off'].iloc[-2] == False) & (df['squeeze_off'].iloc[-1] == True)
+        short_cond1 =  (df['squeeze_off'].iloc[-15] == True) & (df['squeeze_off'].iloc[-14] == True) & (df['squeeze_off'].iloc[-13] == True) & (df['squeeze_off'].iloc[-12] == True) & (df['squeeze_off'].iloc[-11] == True) & (df['squeeze_off'].iloc[-10] == True) & (df['squeeze_off'].iloc[-9] == True) & (df['squeeze_off'].iloc[-8] == True) & (df['squeeze_off'].iloc[-7] == True) & (df['squeeze_off'].iloc[-6] == True) & (df['squeeze_off'].iloc[-5] == True) & (df['squeeze_off'].iloc[-4] == True) & (df['squeeze_off'].iloc[-3] == True) & (df['squeeze_off'].iloc[-2] == True) & (df['squeeze_off'].iloc[-1] == True)
 
 
     # 2. el valor  es negativo => la barra es de color rojo claro
